@@ -19,6 +19,7 @@
 #include <e-util/e-icon-factory.h>
 #include <e-util/e-popup.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib/gi18n.h>
 
 #include "sunone-config-listener.h"
 #include "sunone-permissions-dialog.h"
@@ -63,7 +64,7 @@ static void
 destroy_page (gpointer key, gpointer value, gpointer user_data)
 {
 	g_free (key);
-	gtk_widget_unref (GTK_WIDGET (value));
+	g_object_unref (GTK_WIDGET (value));
 }
 
 static void
@@ -131,7 +132,7 @@ sunone_folder_tree_view_new (SunOneFolderTree *tree, const char *physical_uri)
 
 	widget = sunone_invitation_list_new (model);
 	gtk_widget_show (widget);
-	gtk_widget_ref (widget);
+	g_object_ref (widget);
 
 	return widget;
 }
@@ -142,10 +143,10 @@ sunone_folder_tree_no_view ()
 	static GtkWidget *label = NULL;
 
 	if (!label) {
-		label = gtk_label_new (_("Cannot display this folder in this view.\n Please switch to Calendars/Tasks view to see the calendars/tasks.\n\n This view is used to create or delete calendar/tasks folders,\n manage folder permissions and subscriptions, show your invitations."));
+		label = gtk_label_new (_("To setup a new account, please goto Edit->Preferences->Mail accounts\nand select Sun Calendar WCAP as server type.\n\nThis view is used to create or delete calendar/tasks folders,\nmanage folder permissions and subscriptions, show your invitations.\nPlease switch to Calendars/Tasks view to see the calendars/tasks."));
 		gtk_label_set_justify ((GtkLabel *)label, GTK_JUSTIFY_CENTER);
 	}
-	gtk_widget_ref (label);
+	g_object_ref (label);
 
 	return label;
 }
@@ -909,7 +910,7 @@ sft_popup_rename_folder_response (GtkWidget *dialog, int response, SunOneFolderT
 	GList *l;
 	guint errcode = SUNONE_ERROR_CANNOT_MODIFY_LINKED_OBJECTS;
 	char *physical_uri, *calid, *type, *p;
-	const char *display_name;
+	const char *display_name = NULL;
 
 	g_return_if_fail (SUNONE_IS_FOLDER_TREE (tree));
 
